@@ -27,4 +27,7 @@ worksheet.write('A2', 'World', bold)
 worksheet.write(2, 0, 123)
 worksheet.write(3, 0, 123.456)
 
+# Insert an image.
+worksheet.insert_image('B5', 'logo.png')
+
 workbook.close()
