@@ -591,6 +591,7 @@ class Chart(xmlwriter.XMLwriter):
             'label_position': options.get('label_position'),
             'num_format': options.get('num_format'),
             'num_format_linked': options.get('num_format_linked'),
+            'interval_unit': options.get('interval_unit'),
         }
 
         if 'visible' in options:
@@ -1657,6 +1658,9 @@ class Chart(xmlwriter.XMLwriter):
         # Write the c:labelOffset element.
         self._write_label_offset(100)
 
+        # Write the c:tickLblSkip element.
+        self._write_c_tick_lbl_skip(x_axis.get('interval_unit'))
+
         self._xml_end_tag('c:catAx')
 
     def _write_val_axis(self, args):
@@ -1916,6 +1920,9 @@ class Chart(xmlwriter.XMLwriter):
         # Write the c:labelOffset element.
         self._write_label_offset(100)
 
+        # Write the c:tickLblSkip element.
+        self._write_c_tick_lbl_skip(x_axis.get('interval_unit'))
+
         # Write the c:majorUnit element.
         self._write_c_major_unit(x_axis.get('major_unit'))
 
@@ -2120,6 +2127,15 @@ class Chart(xmlwriter.XMLwriter):
 
         self._xml_empty_tag('c:lblOffset', attributes)
 
+    def _write_c_tick_lbl_skip(self, val):
+        # Write the <c:tickLblSkip> element.
+        if val is None:
+            return
+
+        attributes = [('val', val)]
+
+        self._xml_empty_tag('c:tickLblSkip', attributes)
+
     def _write_major_gridlines(self, gridlines):
         # Write the <c:majorGridlines> element.
 
@@ -2419,10 +2435,15 @@ class Chart(xmlwriter.XMLwriter):
     def _write_rich(self, title, horiz, font):
         # Write the <c:rich> element.
 
+        if font and font.get('rotation'):
+            rotation = font['rotation']
+        else:
+            rotation = None
+
         self._xml_start_tag('c:rich')
 
         # Write the a:bodyPr element.
-        self._write_a_body_pr(horiz)
+        self._write_a_body_pr(rotation, horiz)
 
         # Write the a:lstStyle element.
         self._write_a_lst_style()
@@ -2432,28 +2453,19 @@ class Chart(xmlwriter.XMLwriter):
 
         self._xml_end_tag('c:rich')
 
-    def _write_a_body_pr(self, horiz):
+    def _write_a_body_pr(self, rotation, horiz):
         # Write the <a:bodyPr> element.
-        rot = -5400000
-        vert = 'horz'
-
-        attributes = [
-            ('rot', rot),
-            ('vert', vert),
-        ]
-
-        if not horiz:
-            attributes = []
-
-        self._xml_empty_tag('a:bodyPr', attributes)
-
-    def _write_axis_body_pr(self, rotation):
-        # Write the <a:bodyPr> element for axis fonts.
         attributes = []
 
+        if rotation is None and horiz:
+            rotation = -5400000
+
         if rotation is not None:
             attributes.append(('rot', rotation))
 
+        if horiz:
+            attributes.append(('vert', 'horz'))
+
         self._xml_empty_tag('a:bodyPr', attributes)
 
     def _write_a_lst_style(self):
@@ -2585,10 +2597,15 @@ class Chart(xmlwriter.XMLwriter):
     def _write_tx_pr(self, horiz, font):
         # Write the <c:txPr> element.
 
+        if font and font.get('rotation'):
+            rotation = font['rotation']
+        else:
+            rotation = None
+
         self._xml_start_tag('c:txPr')
 
         # Write the a:bodyPr element.
-        self._write_a_body_pr(horiz)
+        self._write_a_body_pr(rotation, horiz)
 
         # Write the a:lstStyle element.
         self._write_a_lst_style()
@@ -3092,7 +3109,7 @@ class Chart(xmlwriter.XMLwriter):
             return
 
         self._xml_start_tag('c:txPr')
-        self._write_axis_body_pr(font.get('rotation'))
+        self._write_a_body_pr(font.get('rotation'), None)
         self._write_a_lst_style()
         self._xml_start_tag('a:p')
 
